pub trait Stream:
StreamOnce
+ ResetStream
+ Positioned { }Expand description
A stream of tokens which can be duplicated
This is a trait over types which implement the StreamOnce, ResetStream and Positioned
traits. If you need a custom Stream object then implement those traits and Stream is
implemented automatically.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".